==> haskell-crypto-numbers-0.2.7-91-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-475EamL4Z5s2du8VqHHmMH
key: crypto-numbers-0.2.7-475EamL4Z5s2du8VqHHmMH
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
abi: 402d00364b9164001dc89f18cd6aa32d
exposed: True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-475EamL4Z5s2du8VqHHmMH
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333 ghc-prim-0.5.3
    integer-gmp-1.0.2.0 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-numbers-0.2.7-104-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-numbers
version: 0.2.7
id: crypto-numbers-0.2.7-6ucSnykmfDKH8vkRZJKn3K
key: crypto-numbers-0.2.7-6ucSnykmfDKH8vkRZJKn3K
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-numbers
synopsis: Cryptographic numbers: functions and algorithms
description:
    Cryptographic numbers: functions and algorithms
category: Cryptography
abi: b9003f377e60bd864acd6d706d3c95bd
exposed: True
exposed-modules:
    Crypto.Number.Basic Crypto.Number.F2m Crypto.Number.Generate
    Crypto.Number.ModArithmetic Crypto.Number.Polynomial
    Crypto.Number.Prime Crypto.Number.Serialize
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-numbers-0.2.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-numbers-0.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-numbers-0.2.7
hs-libraries: HScrypto-numbers-0.2.7-6ucSnykmfDKH8vkRZJKn3K
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    crypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H ghc-prim-0.5.3
    integer-gmp-1.0.2.0 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-crypto-numbers/html/crypto-numbers.haddock
haddock-html: /usr/share/doc/haskell-crypto-numbers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
